clear
clc
//Ejemplo de aplicación de tres reglas de cuadratura:
//1) Extremo inferior del intervalo
//2) Regla del trapezoide
//3) Regla de Simpson
//En este ejemplo presentamos tres reglas diferentes de cuadratura.
//En primer lugar mostramos una regla de cuadratura donde f(x) únicamente se evalúa en el lado
//izquierdo de cada panel.
//Evaluaremos la integral para diferentes discretizaciones con el propósito de determinar el
//orden de la regla. Aplicaremos código a la función f(x)=exp(x).
//
//Primero fijamos el intervalo:
a=1
b=3
//y el número de evaluaciones de la integral,
m=5
for i=1:m;
 //Seguidamente establecemos el tamaño del panel:
 n=2^(i-1);
 dx=(b-a)/n;
 x=[a:dx:b];
 //ahora la función de ponderación
 w=ones(1,n);
 w(1,n+1)=0;
 //y el resultado:
 f=exp(x);
 integral_1(i)=dx * w * f';
 h(i)=dx;
end;
disp('Integral 1: Extremo inferior del intervalo:'),integral_1(m)
//Ahora hacemos lo mismo con la regla del trapezoide:
for i=1:m,
 //Establecemos el tamaño del panel:
 n=2^(i-1);
 dx=(b-a)/n;
 x=[a:dx:b];
 //la función de ponderación o de peso:
 w=ones(1,n);
 w(1,n+1)=.5;
 w(1,1)=.5;
 //y el resultado:
 f=exp(x);
 integral_2(i)=dx * w * f';
 trh(i)=dx;
end;
disp('Integral 2: Regla del trapecio:'),integral_2(m)
//Finalmente, para la regla de Simpson tenemos:
for i=1:m,
 //Establecemos el tamaño del panel:
 n=2^(i-1);
 dx=(b-a)/n;
 x=[a:dx:b];
 //la función de peso:
 w=2*ones(1,n)/3.;
 w(2:2:n)=w(2:2:n)+2./3.;
 w(1,n+1)=1/3.;
 w(1,1)=1/3.;
 //y el resultado:
 f=exp(x);
 integral_3(i)=dx * w * f';
 sih(i)=dx;
end;
disp('Integral 3: Regla de Simpson:'),integral_3(m)
//Graficamos los errores:
//Calculamos el error:
error1=integral_1-(exp(b)-exp(a));
trerror=integral_2-(exp(b)-exp(a));
sierror=integral_3-(exp(b)-exp(a));
//Finalmente comparamos los errores.
er=[abs(error1),abs(trerror),abs(sierror)];
plot2d('ll',h,[er(:,1),er(:,2),er(:,3)],[1:3],leg='Extremo Inferior del Intervalo@Regla del Trapezoide@Regla de Simpson')
gca().grid=[1 1 1]
xlabel('h')
ylabel('Error absoluto')
title('Errores Absolutos de las Reglas de Cuadratura')
//
//Como puede verse, la pendiente del primer algoritmo es uno, suministrando un error
//de O(h), la pendiente de la regla del trapezoide es de O(h^2), y la pendiente de la regla de
//Simpson es de O(h^4).
